@@ -37,6 +37,7 @@ my @knwonBuildFiles = (
     #[ 'tsconfig.json'     => ['tsc'] ],
     [ 'gulpfile.js'       => ['gulp'] ],
     [ 'rollup.config.js'  => [ 'rollup',  '-c' ] ],
+    [ 'rollup.config.mjs' => [ 'rollup',  '-c' ] ],
     [ 'webpack.config.js' => [ 'webpack', '--mode', 'production' ] ],
     [ 'webpackfile.js'    => [ 'webpack', '--mode', 'production' ] ],
 );
@@ -846,6 +847,17 @@ sub clean {
     clean_build_modules();
     clean_test_modules();
 
+    # Restore package.json if mjs2cjs modified it
+    if ( -e '.mjs2cjs-package.json' ) {
+        print "Restoring package.json modified by mjs2cjs\n";
+        unlink 'package.json';
+        rename '.mjs2cjs-package.json', 'package.json';
+        if ( -e 'debian/index.cjs' ) {
+            print "Delete index.cjs\n";
+            unlink 'index.cjs';
+        }
+    }
+
     # Clean test link
     if ( my $p = $self->main_package ) {
         $self->do_unlink( 'node_modules/' . $self->pjson($p)->{name} );
