@@ -14,7 +14,7 @@ our $BUILTUSING = {};
 our $PACKAGES   = {};
 our $PATHS      = {};
 
-my $WEBPACKS = qr/^.*(?:browserify|webpack|rollup).*$/i;
+my $WEBPACKS = qr/^.*\b(?:node-(?:rollup-plugin-node-resolve|esbuild)|browserify(?:-lite)?|esbuild|webpack)\b.*/i;
 *debug = \&Debian::PkgJs::Utils::debug;
 
 sub nodepathNoError {
